package com.yunzhi.nanyang.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.HttpUtils;
import com.yunzhi.nanyang.common.ResponseBean;

import java.time.LocalDateTime;
import java.util.List;

import com.yunzhi.nanyang.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.nanyang.entity.TdRawDevice;
import com.yunzhi.nanyang.service.TdRawDeviceService;

/**
 * 原始设备信息;(td_raw_device)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-11-3
 */
@Api(tags = "原始设备信息对象功能接口")
@RestController
@RequestMapping("/")
public class TdRawDeviceController extends BaseController {

    @Value("${device.server}")
    String deviceServer;

    @Autowired
    HttpUtils httpUtils;

    @Autowired
    private TdRawDeviceService tdRawDeviceService;

//    /** 
//     * 通过ID查询单条数据 
//     *
//     * @param deviceId 主键
//     * @return 实例对象
//     */
//    @ApiOperation("通过ID查询单条数据")
//    @GetMapping("/raw-device/{id}")
//    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
//        return ResponseBean.success(tdRawDeviceService.getById(id));
//    }

//    /**
//     * 分页查询
//     *
//     * @param pageNum  当前页码
//     * @param pageSize 每页条数
//     * @return 查询结果
//     */
//    @ApiOperation("分页查询")
//    @GetMapping("/admin/raw-device")
//    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
//                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
//                             @ApiParam("设备分类") @RequestParam(value = "deviceKind", required = false) String deviceKind,
//                             @ApiParam("设备状态") @RequestParam(value = "deviceStatus", required = false) Integer deviceStatus) throws Exception {
//
//        IPage<TdRawDevice> pg = new Page<>(pageNum, pageSize);
//        QueryWrapper<TdRawDevice> queryWrapper = new QueryWrapper<>();
//        queryWrapper.eq(!StringUtils.isEmpty(deviceKind), "device_kind", deviceKind);
//        queryWrapper.eq(null != deviceStatus, "device_status", deviceStatus);
//        queryWrapper.orderByDesc("create_date");
//        IPage<TdRawDevice> result = tdRawDeviceService.page(pg);
//
//        return ResponseBean.success(result);
//    }

    /**
     * 新增数据
     *
     * @param tdRawDevice 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增设备")
    @PostMapping("/admin/raw-device")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TdRawDevice tdRawDevice) throws Exception {

        if (StringUtils.isEmpty(tdRawDevice.getDeviceKind())) {
            return ResponseBean.error("设备大类不能为空");
        }

        if (StringUtils.isEmpty(tdRawDevice.getDeviceNo())) {
            return ResponseBean.error("设备号不能为空");
        }

        QueryWrapper<TdRawDevice> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("device_kind", tdRawDevice.getDeviceKind());
        queryWrapper.eq("device_no", tdRawDevice.getDeviceNo());

        TdRawDevice origin = tdRawDeviceService.getOne(queryWrapper);
        if (null != origin) {
            return ResponseBean.error("当前设备号已存在");
        }

        tdRawDevice.setDeviceStatus(0); // 默认离线
        tdRawDevice.setCreateDate(LocalDateTime.now());
        tdRawDeviceService.save(tdRawDevice);
        return ResponseBean.success(tdRawDevice);
    }

    /**
     * 同步设备
     *
     * @param
     * @return 实例对象
     */
    @ApiOperation("同步设备")
    @PutMapping("/raw-device/sync")
    public ResponseBean sync() throws Exception {
        String url = deviceServer + "/shensong/syncDevice";
        String s = httpUtils.get(url);
        return JSONObject.parseObject(s, ResponseBean.class);
    }
//    
//    /** 
//     * 通过主键删除数据
//     *
//     * @param deviceId 主键
//     * @return 是否成功
//     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/raw-device/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
//        tdRawDeviceService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }
}